@@ -14,7 +14,10 @@ from dtrace import DTraceConsumer
 SCRIPT = 'sysinfo:::readch { @dist[execname] = quantize(arg0); }'
 
 
-def my_walk(id, key, values):
+def my_walk(action, identifier, key, values):
+    '''
+    Walk the aggregrate.
+    '''
     print key
     for item in values:
         if item[0][0] > 0 and item[1] > 0:
@@ -30,4 +33,3 @@ def main():
 
 if __name__ == '__main__':
     main()
-
